@@ -1,9 +1,9 @@
 from typing import Tuple, Optional, List, Dict, TypeVar, TypeAlias
 
-S = TypeVar('S')
-T = TypeVar('T')
+S = TypeVar("S")
+T = TypeVar("T")
 
-ParseTree = Tuple[str, Optional[List['ParseTree']]]
+ParseTree = Tuple[str, Optional[List["ParseTree"]]]
 Path = Tuple[int, ...]
 Grammar = Dict[str, List[str]]
 ImmutableGrammar = Tuple[Tuple[str, Tuple[str, ...]], ...]
